@@ -861,11 +861,15 @@ impl SydMsFlags {
 #[inline]
 pub(crate) fn op2name(op: u8) -> &'static str {
     match op {
+        0x1 => "socket",
         0x2 => "bind",
         0x3 => "connect",
         0x5 => "accept",
         0x6 => "getsockname",
+        0x7 => "getpeername",
+        0x9 => "send",
         0xb => "sendto",
+        0xf => "getsockopt",
         0x10 => "sendmsg",
         0x12 => "accept4",
         0x14 => "sendmmsg",
